@@ -375,8 +375,8 @@ class Tensor:
     def __init__ (self, val = np.array([1.0])):
         """
         Initialize Tensor object.
-        val (float or int). 
-        Attributes (all private):
+        val (scalar/list/np.ndarray)
+        Attributes:
         =============
         self.val (number): the value of the Tensor
         self.der (number): the derivative of the Tensor
@@ -603,29 +603,6 @@ class Tensor:
                 x._der = other * self._val ** (other - 1) * self._der
                 return x
 
-        # elif check_array(other) and (len(other) == len(self) or len(self) == 1): 
-        #     if check_anyzero(other): # one of the values in other is 0
-        #         x._val = np.zeros(len(other))
-        #         x._der = np.zeros(len(other))
-        #         if len(self) == 1:
-                     
-        #         for i,v in enumerate(len(other)):
-        #             try:
-                           
-                            
-        #                 elif len(self) == len(other):
-        #                     t = Tensor(self._val[i]).__pow__(v) 
-        #                 return x
-        #             except:
-        #                 raise AttributeError
-                    
-            # elif ((self._val == 0) & (other <1)).any():
-            #     raise ZeroDivisionError('the base cannot be 0 when power is negative')
-            # else:
-            #     other = other.astype(float) #convert to float first
-            #     x._val  = self._val** other
-            #     x._der = other * self._val ** (other - 1) * self._der
-            #     return x
         else:
             raise TypeError('Tensor base can only be operated with a Tensor object or a number/np.ndarray')
        
@@ -641,17 +618,6 @@ class Tensor:
         """
         x = Tensor()
 
-        # if (self._val <=0).any():
-        #     raise ValueError('log function undefined for exponent <= 0')
-
-        # if isinstance(other, Tensor): # x**a -> a*x**(a-1)
-        #     if (other.val > 0).all():
-        #         x._val = self._val ** other.val
-        #         #x._der = (self._val ** other.val) * (other.der * np.log (self._val) + other.val * self._der/ self._val)
-        #         x._der = other.der/other.val*(self._der*other.val**self._val+self._val*other.val**self._val*np.log(self._val))
-        #         return x
-        #     else:
-        #         raise ValueError('log function undefined for exponent <= 0')
 
         if check_number(other) or (check_array(other) and len(other) == 1): 
             if other <= 0:
@@ -660,13 +626,6 @@ class Tensor:
                 x._val  = other ** self._val
                 x._der = (other ** self._val) * (self._der * np.log(other))
                 return x
-        # elif check_array(other):  
-        #     if (other <= 0).any():
-        #         raise ValueError('log function undefined for exponent <= 0')
-        #     else:
-        #         x._val  = other ** self._val
-        #         x._der = other ** self._val * (self._der * np.log(other))
-        #         return x
 
         else:
             raise TypeError('Tensor base can only be operated with a Tensor object or a number/np.ndarray')
